/**
 * @file
 */

(function ($) {
    'use strict';
    Drupal.behaviors.handsontablejson = {
        attach: function (context, settings) {

            var renderedTables = $(document).find('.rendered-table.format-json');

            renderedTables.each(function () {

                var textarea = $(this).parents('.field--type-table').find('input[type="hidden"]');
                if ((($(textarea).val()).length > 0) && (($(this).html()) == '')) {
                    var config = $(this).parents('.field--type-table').find('.table-config');
                    var rows = 1;
                    var columns = 2;

                    if ((config.length > 0)
                        && (($(config).val()).length > 0)
                        && (($(this).html()) == '')) {
                        config = JSON.parse(config.val());
                        rows = config.rows !== undefined ? config.rows : 1;
                        columns = config.columns !== undefined ? config.columns : 2;
                        config = config.value;
                    }
                    var data = JSON.parse($(textarea).val());
                    var header = data[0];
                    var table = new Handsontable(this, {
                        data: data,
                        cells: function (row, col, prop) {
                            var cellProperties = {};
                            if (config[row] !== undefined && config[row][col] !== undefined) {
                                cellProperties.placeholder = config[row][col];
                            }

                            return cellProperties;
                        },
                        minRows: rows,
                        minCols: columns,
                        stretchH: 'all',
                        contextMenu: {
                          items: {
                            'row_above': {
                              "name": Drupal.t('Insert row above'),
                            },
                            'row_below': {
                              "name": Drupal.t('Insert row below'),
                            },
                            'hsep1': "---------",
                            'col_left': {
                              "name": Drupal.t('Insert column on the left'),
                            },
                            'col_right': {
                              "name": Drupal.t('Insert column on the right'),
                            },
                            'hsep2': '---------',
                            'remove_row': {
                              "name": Drupal.t('Remove row'),
                            },
                            'remove_col': {
                              "name": Drupal.t('Remove column'),
                            },
                            'hsep3': '---------',
                            'undo': {
                              "name": Drupal.t('Undo'),
                            },
                            'redo': {
                              "name": Drupal.t('Redo'),
                            },
                            'hsep4': "---------",
                            'cut': {
                              "name": Drupal.t('Cut'),
                            },
                            'copy': {
                              "name": Drupal.t('Copy'),
                            },
                          }
                        },
                    });

                    table.updateSettings({
                        afterChange: function (e) {
                            $(textarea).val(JSON.stringify(table.getData()));
                        },
                        afterCreateRow: function (index, amount) {
                            $(textarea).val(JSON.stringify(table.getData()));
                        },
                        afterRemoveCol: function (index, amount) {
                            $(textarea).val(JSON.stringify(table.getData()));
                        },
                        afterRowMove: function (index, amount) {
                            $(textarea).val(JSON.stringify(table.getData()));
                        },
                        afterRemoveRow: function (index, amount) {
                            $(textarea).val(JSON.stringify(table.getData()));
                        },
                        afterCreateCol: function (index, amount) {
                          $(textarea).val(JSON.stringify(table.getData()));
                        }
                    });
                }

            });

        }
    };
}(jQuery));
